"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const generate_env_1 = require("../lib/generate-env");
const fs_1 = require("../lib/utils/fs");
class GenDotEnvName extends core_1.Command {
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { flags } = yield this.parse(GenDotEnvName);
            const envNames = (0, generate_env_1.generateDotEnvName)(flags['source-file']);
            const fileContent = `export const AllProjectEnvNames = ${JSON.stringify(envNames, null, 2)} as const;
export type ProjectEnvName = keyof typeof AllProjectEnvNames;`;
            if (flags.output) {
                (0, fs_1.outputFile)(flags.output, fileContent);
            }
            else {
                console.log(fileContent);
            }
        });
    }
}
exports.default = GenDotEnvName;
GenDotEnvName.description = 'Generate .env name type definition';
GenDotEnvName.examples = [
    `$ typed-env gen-dot-env-name -s .env -o ./src/env.d.ts`,
];
GenDotEnvName.flags = {
    'source-file': core_1.Flags.string({
        char: 's',
        description: 'enter the file path to check',
        required: true,
    }),
    output: core_1.Flags.string({
        char: 'o',
        description: 'enter the output file path',
    }),
};
