"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getArgsFromOneCall = exports.getArgsFromCall = void 0;
const ts_morph_1 = require("ts-morph");
function getArgsFromCall(args) {
    const { source, filePath, chainCallFuncNames } = args;
    const calls = source.getDescendantsOfKind(ts_morph_1.SyntaxKind.CallExpression);
    const argsInfo = [];
    for (const c of calls) {
        const result = getArgsFromOneCall({
            source: c,
            filePath,
            chainCallFuncNames,
        });
        result && argsInfo.push(result);
    }
    return argsInfo;
}
exports.getArgsFromCall = getArgsFromCall;
function getArgsFromOneCall({ source, filePath, chainCallFuncNames, }) {
    var _a;
    if (!source) {
        return;
    }
    const pe = source.getExpressionIfKind(ts_morph_1.SyntaxKind.PropertyAccessExpression);
    const peName = pe === null || pe === void 0 ? void 0 : pe.getName();
    if (peName && chainCallFuncNames.includes(peName)) {
        return generateArgINfo({
            filePath,
            funcName: peName,
            source,
        });
    }
    const identifierText = (_a = source
        .getExpressionIfKind(ts_morph_1.SyntaxKind.Identifier)) === null || _a === void 0 ? void 0 : _a.getText();
    if (identifierText && chainCallFuncNames.includes(identifierText)) {
        return generateArgINfo({
            filePath,
            funcName: identifierText,
            source,
        });
    }
}
exports.getArgsFromOneCall = getArgsFromOneCall;
const generateArgINfo = ({ filePath, funcName, source, }) => {
    return {
        path: `${filePath}#L${source.getStartLineNumber()}#S${source.getFullStart()}`,
        pos: {
            line: source.getStartLineNumber(),
            fullStart: source.getFullStart(),
        },
        funcName,
        args: source.getArguments().map((r) => r.getText()),
    };
};
