"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCallUsageArgsFromStatement = void 0;
const ts_morph_1 = require("ts-morph");
const call_1 = require("./call");
function getCallUsageArgsFromStatement(args) {
    return reduceOfGetArgs(args)(allSingleStatment(args.source), [
        ...variableStatement(args),
        ...ifStatement(args),
        ...switchStatement(args),
        ...doStatement(args),
    ]);
}
exports.getCallUsageArgsFromStatement = getCallUsageArgsFromStatement;
function allSingleStatment(source) {
    return [
        ...source.getDescendantsOfKind(ts_morph_1.SyntaxKind.EmptyStatement),
        // ...source.getDescendantsOfKind(SyntaxKind.VariableStatement),
        ...source.getDescendantsOfKind(ts_morph_1.SyntaxKind.ExpressionStatement),
        // ...source.getDescendantsOfKind(SyntaxKind.IfStatement),
        // ...source.getDescendantsOfKind(SyntaxKind.DoStatement),
        ...source.getDescendantsOfKind(ts_morph_1.SyntaxKind.WhileStatement),
        ...source.getDescendantsOfKind(ts_morph_1.SyntaxKind.ForStatement),
        ...source.getDescendantsOfKind(ts_morph_1.SyntaxKind.ForInStatement),
        ...source.getDescendantsOfKind(ts_morph_1.SyntaxKind.ForOfStatement),
        ...source.getDescendantsOfKind(ts_morph_1.SyntaxKind.ContinueStatement),
        ...source.getDescendantsOfKind(ts_morph_1.SyntaxKind.BreakStatement),
        ...source.getDescendantsOfKind(ts_morph_1.SyntaxKind.ReturnStatement),
        ...source.getDescendantsOfKind(ts_morph_1.SyntaxKind.WithStatement),
        // ...source.getDescendantsOfKind(SyntaxKind.SwitchStatement),
        ...source.getDescendantsOfKind(ts_morph_1.SyntaxKind.LabeledStatement),
        ...source.getDescendantsOfKind(ts_morph_1.SyntaxKind.ThrowStatement),
        ...source.getDescendantsOfKind(ts_morph_1.SyntaxKind.TryStatement),
        ...source.getDescendantsOfKind(ts_morph_1.SyntaxKind.DebuggerStatement),
        ...source.getDescendantsOfKind(ts_morph_1.SyntaxKind.FunctionDeclaration),
    ];
}
function variableStatement(args) {
    const statements = args.source.getDescendantsOfKind(ts_morph_1.SyntaxKind.VariableStatement);
    return statements.reduce((acc, cur) => {
        return [
            ...acc,
            ...reduceOfGetArgs(args)(cur.getDescendantsOfKind(ts_morph_1.SyntaxKind.TemplateSpan)),
        ];
    }, []);
}
function doStatement(args) {
    const statements = args.source.getDescendantsOfKind(ts_morph_1.SyntaxKind.DoStatement);
    return statements.reduce((acc, cur) => {
        const result = (0, call_1.getArgsFromOneCall)({
            source: cur.getExpressionIfKind(ts_morph_1.SyntaxKind.CallExpression),
            filePath: args.filePath,
            chainCallFuncNames: args.chainCallFuncNames,
        });
        return [
            ...acc,
            ...reduceOfGetArgs(args)(cur.getDescendantsOfKind(ts_morph_1.SyntaxKind.Block)),
            ...[result ? [result] : []],
        ];
    }, []);
}
function ifStatement(args) {
    const { filePath, chainCallFuncNames } = args;
    const statements = args.source.getDescendantsOfKind(ts_morph_1.SyntaxKind.IfStatement);
    return statements.reduce((acc, cur) => {
        const subIf = cur.getDescendantsOfKind(ts_morph_1.SyntaxKind.IfStatement);
        let subResult = [];
        if (subIf.length > 0) {
            subResult = ifStatement({
                source: cur,
                filePath,
                chainCallFuncNames,
            });
        }
        const result = (0, call_1.getArgsFromCall)({
            source: cur,
            filePath,
            chainCallFuncNames,
        });
        return [...acc, result, ...subResult];
    }, []);
}
function switchStatement(args) {
    const { filePath, chainCallFuncNames } = args;
    const statements = args.source.getDescendantsOfKind(ts_morph_1.SyntaxKind.SwitchStatement);
    return statements.reduce((acc, cur) => {
        const caseBlock = cur.getDescendantsOfKind(ts_morph_1.SyntaxKind.CaseBlock);
        const caseBlockResult = caseBlock.reduce((acc, cur) => {
            return [
                ...acc,
                ...reduceOfGetArgs(args)(cur.getDescendantsOfKind(ts_morph_1.SyntaxKind.CaseClause)),
                ...reduceOfGetArgs(args)(cur.getDescendantsOfKind(ts_morph_1.SyntaxKind.DefaultClause)),
            ];
        }, []);
        const result = (0, call_1.getArgsFromCall)({
            source: cur,
            filePath,
            chainCallFuncNames,
        });
        return [...acc, result, ...caseBlockResult];
    }, []);
}
function reduceOfGetArgs(args) {
    return (source, initValue) => source.reduce(getArgs(args), initValue !== null && initValue !== void 0 ? initValue : []);
}
function getArgs(args) {
    const { filePath, chainCallFuncNames } = args;
    return (acc, cur) => {
        const result = (0, call_1.getArgsFromCall)({
            source: cur,
            filePath,
            chainCallFuncNames,
        });
        return [...acc, result];
    };
}
