"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateDotEnvName = exports.generateEnvByTypedEnv = exports.generateEnvNameByTypedEnv = void 0;
const tslib_1 = require("tslib");
const util_1 = require("./utils/util");
const generate_typed_env_call_usage_report_1 = require("./generate-typed-env-call-usage-report");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const generateEnvNameByTypedEnv = (arg) => {
    const envNames = (0, generate_typed_env_call_usage_report_1.generateTypedEnvCallUsageReport)(arg).envNames.reduce((pre, current) => {
        return Object.assign(Object.assign({}, pre), { [current]: current });
    }, {});
    return envNames;
};
exports.generateEnvNameByTypedEnv = generateEnvNameByTypedEnv;
const generateEnvByTypedEnv = (arg) => {
    const report = (0, generate_typed_env_call_usage_report_1.generateTypedEnvCallUsageReport)(arg);
    const envValue = report.envNames.reduce((acc, cur) => {
        const envInfo = report.data[cur];
        const paths = Object.keys(envInfo);
        const values = (0, util_1.uniqBy)(paths.map((p) => envInfo[p].default).filter((r) => r != null), (t) => t);
        if (values.length > 1) {
            acc.push(`// default=[${values.join(',')}]`);
            acc.push(`${cur}=${values[0]}`);
        }
        else if (values.length === 1 && values[0].length > 0) {
            if (["''", '""'].includes(values[0])) {
                acc.push(`// default=[${values.join(',')}]`);
            }
            acc.push(`${cur}=`);
        }
        else {
            acc.push(`${cur}=`);
        }
        return acc;
    }, []);
    return envValue;
};
exports.generateEnvByTypedEnv = generateEnvByTypedEnv;
const generateDotEnvName = (envPath) => {
    const filePath = path_1.default.resolve(envPath);
    if (!fs_1.default.existsSync(filePath)) {
        throw new Error(`File not found: ${filePath}`);
    }
    const env = fs_1.default.readFileSync(filePath, { encoding: 'utf-8' });
    const envJson = (0, util_1.parseEnv)(env);
    const envNames = {};
    for (const [k] of Object.entries(envJson)) {
        envNames[k] = k;
    }
    return envNames;
};
exports.generateDotEnvName = generateDotEnvName;
